summaryrefslogtreecommitdiff
path: root/mpn/vax/sub_n.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/vax/sub_n.s')
-rw-r--r--mpn/vax/sub_n.s6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpn/vax/sub_n.s b/mpn/vax/sub_n.s
index ed68b0f16..7c486c679 100644
--- a/mpn/vax/sub_n.s
+++ b/mpn/vax/sub_n.s
@@ -1,4 +1,4 @@
# VAX __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and store
# difference in a third limb vector.
# Copyright (C) 1999 Free Software Foundation, Inc.
@@ -29,8 +29,8 @@
.text
.align 1
-.globl ___mpn_sub_n
-___mpn_sub_n:
+.globl ___gmpn_sub_n
+___gmpn_sub_n:
.word 0x0
movl 16(ap),r0
movl 12(ap),r1
@@ -1,4 +1,4 @@
-# VAX __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and store
+# VAX __gmpn_sub_n -- Subtract two limb vectors of the same length > 0 and store
# difference in a third limb vector.
# Copyright (C) 1999 Free Software Foundation, Inc.